@@ -701,3 +701,53 @@ def range_check_bkg_subtracted(
             ]
 
     return result
+
+
+def branches_exist(
+    filepath_list,
+    branches,
+    tree_pattern=r"(.*/DecayTree)|(.*/MCDecayTree)",
+):
+    """Check that all matching TTree objects contain a minimum number of entries.
+
+    :param filepath_list: List of paths to files to analyse
+    :param branches: List of branches that will be required to exist in TTree objects
+    :param tree_pattern: A regular expression for the TTree objects to check
+    :returns: A CheckResult object, containing no tree_data key/values (empty dict)
+    """
+    result = CheckResult("branches_exist", True)
+    for filepath in filepath_list:
+        trees_opened = []
+        with uproot.open(filepath) as f:
+            for key, obj in f.items(cycle=False):
+                if not isinstance(obj, uproot.TTree):
+                    continue
+                if not re.fullmatch(tree_pattern, key):
+                    continue
+                if key in trees_opened:
+                    continue
+                trees_opened.append(key)
+
+                # First time: initialise the CheckResult
+                if key not in result.tree_data:
+                    result.tree_data[key] = {}
+
+                # Check that branches exist
+                if not set(branches).issubset(obj.keys()):
+                    missing_branches = list(set(branches) - set(obj.keys()))
+                    result.passed = False
+                    result.messages += [
+                        f"Required branches not found in Tree {key}: {missing_branches}"
+                    ]
+
+    # If no matches are found the check should be marked as failed, and can return early
+    if len(result.tree_data) == 0:
+        result.passed = False
+        result.messages += [f"No TTree objects found that match {tree_pattern}"]
+        return result
+
+    if result.passed:
+        for key, _data in result.tree_data.items():
+            result.messages += [f"All required branches were found in Tree {key}"]
+
+    return result
