@@ -413,3 +413,29 @@ def test_range_check_bkg_subtracted_failing_tree_name():
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
     assert list(result.tree_data.keys()) == []
+
+
+def test_branches_exist_passing():
+    result = checks.branches_exist(
+        [
+            "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
+        ],
+        ["H1_PZ", "H2_PZ"],
+        "DecayTree",
+    )
+    assert result.passed
+    assert result.messages == ["All required branches were found in Tree DecayTree"]
+
+
+def test_branches_exist_failing_missing_branches():
+    result = checks.branches_exist(
+        [
+            "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
+        ],
+        ["H1_PZ", "H2_PZ", "RandomName"],
+        "DecayTree",
+    )
+    assert not result.passed
+    assert result.messages == [
+        "Required branches not found in Tree DecayTree: ['RandomName']"
+    ]
